@@ -1,5 +1,7 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+// SPDX-FileCopyrightInfo: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-GPL-2.0-only-with-dune-grid-glue-exception
 
 #include <dune/grid-glue/common/crossproduct.hh>
 #include <dune/grid-glue/common/projection.hh>
@@ -16,7 +18,7 @@ void ContactMerge<dimworld, T>::computeIntersections(const Dune::GeometryType& g
                                    const std::vector<Dune::FieldVector<T,dimworld> >& grid2ElementCorners,
                                    std::bitset<(1<<dim)>& neighborIntersects2,
                                    unsigned int grid2Index,
-                                   std::vector<RemoteSimplicialIntersection>& intersections)
+                                   std::vector<SimplicialIntersection>& intersections)
 {
     using std::get;
 
@@ -113,7 +115,7 @@ void ContactMerge<dimworld, T>::computeIntersections(const Dune::GeometryType& g
     const auto& refTar = Dune::ReferenceElements<T,dim>::general(elementTypes[tarGrid]);
     for (int i=0; i<refTar.size(1); i++) {
 
-        // if all face corners hit the the other element then
+        // if all face corners hit the other element then
         // the neighbor might also intersect
 
         bool intersects(true);
@@ -127,7 +129,7 @@ void ContactMerge<dimworld, T>::computeIntersections(const Dune::GeometryType& g
     const auto& refDom = Dune::ReferenceElements<T,dim>::general(elementTypes[domGrid]);
     for (int i=0; i<refDom.size(1); i++) {
 
-        // if all face corners hit the the other element then
+        // if all face corners hit the other element then
         // the neighbor might also intersect
 
         bool intersects(true);
@@ -159,13 +161,11 @@ void ContactMerge<dimworld, T>::computeIntersections(const Dune::GeometryType& g
     if (nPolyCorners==dim+1) {
 
      //   std::cout<<"Add intersection: 1\n";
-        typename Base::RemoteSimplicialIntersection intersect;
-        intersect.grid1Entities_[0] = grid1Index;
-        intersect.grid2Entities_[0] = grid2Index;
+        typename Base::SimplicialIntersection intersect(grid1Index, grid2Index);
 
         for (int j=0;j<dim+1; j++) {
-            intersect.grid1Local_[0][j]=polytopeCorners[j][0];
-            intersect.grid2Local_[0][j]=polytopeCorners[j][1];
+            intersect.corners0[0][j]=polytopeCorners[j][0];
+            intersect.corners1[0][j]=polytopeCorners[j][1];
         }
         intersections.push_back(intersect);
 
@@ -195,18 +195,16 @@ void ContactMerge<dimworld, T>::computeIntersections(const Dune::GeometryType& g
 
     for (size_t i=1; i<polytopeCorners.size()-1; i++) {
 
-        typename Base::RemoteSimplicialIntersection intersect;
-        intersect.grid1Entities_[0] = grid1Index;
-        intersect.grid2Entities_[0] = grid2Index;
+        typename Base::SimplicialIntersection intersect(grid1Index, grid2Index);
 
         for (int j=0;j<dim; j++) {
-            intersect.grid1Local_[0][j]=polytopeCorners[ordering[i+j]][0];
-            intersect.grid2Local_[0][j]=polytopeCorners[ordering[i+j]][1];
+            intersect.corners0[0][j]=polytopeCorners[ordering[i+j]][0];
+            intersect.corners1[0][j]=polytopeCorners[ordering[i+j]][1];
         }
 
         // last corner is the first for all intersections
-        intersect.grid1Local_[0][dim]=polytopeCorners[ordering[0]][0];
-        intersect.grid2Local_[0][dim]=polytopeCorners[ordering[0]][1];
+        intersect.corners0[0][dim]=polytopeCorners[ordering[0]][0];
+        intersect.corners1[0][dim]=polytopeCorners[ordering[0]][1];
 
         intersections.push_back(intersect);
     }
